from enum import Enum


class UnitRadioactivityFormat(str, Enum):
    BECQUEREL = 'becquerel'
    CURIE = 'curie'
    RUTHERFORD = 'rutherford'

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class UnitIlluminanceFormat(str, Enum):
    LUX = 'lux'
    FOOTCANDLE = 'footcandle'
    LUMENS_PER_SQUARE_INCH = 'lumens_per_square_inch'
    PHOT = 'phot'

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class UnitSolidAngleFormat(str, Enum):
    STERADIAN = 'steradian'
    DEGREE_SQUARED = 'degree_squared'
    SPAT = 'spat'

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class UnitVolumeFormat(str, Enum):
    CUBIC_METER = 'cubic_meter'
    CUBIC_CENTIMETER = 'cubic_centimeter'
    CUBIC_MILLIMETER = 'cubic_millimeter'
    CUBIC_KILOMETER = 'cubic_kilometer'
    LITER = 'liter'
    CUBIC_INCH = 'cubic_inch'
    CUBIC_FOOT = 'cubic_foot'
    CUBIC_YARD = 'cubic_yard'
    CUBIC_MILE = 'cubic_mile'
    GALLON = 'gallon'
    QUART = 'quart'
    PINT = 'pint'
    CUP = 'cup'
    FLUID_OUNCE = 'fluid_ounce'
    BARREL = 'barrel'
    BUSHEL = 'bushel'
    CORD = 'cord'
    CUBIC_FATHOM = 'cubic_fathom'
    TABLESPOON = 'tablespoon'
    TEASPOON = 'teaspoon'
    PINCH = 'pinch'
    DASH = 'dash'
    DROP = 'drop'
    FIFTH = 'fifth'
    DRAM = 'dram'
    GILL = 'gill'
    PECK = 'peck'
    SACK = 'sack'
    SHOT = 'shot'
    STRIKE = 'strike'

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class UnitMassFormat(str, Enum):
    GRAM = 'gram'
    KILOGRAM = 'kilogram'
    METRIC_TON = 'metric_ton'
    POUND = 'pound'
    LONG_TON = 'long_ton'
    SHORT_TON = 'short_ton'
    STONE = 'stone'
    OUNCE = 'ounce'
    CARAT = 'carat'
    SLUG = 'slug'

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class UnitEnergyFormat(str, Enum):
    JOULE = 'joule'
    CALORIE = 'calorie'
    KILOWATT_HOUR = 'kilowatt_hour'
    WATT_HOUR = 'watt_hour'
    BRITISH_THERMAL_UNIT = 'british_thermal_unit'
    BRITISH_THERMAL_UNIT_ISO = 'british_thermal_unit_iso'
    BRITISH_THERMAL_UNIT59 = 'british_thermal_unit59'
    THERM = 'therm'
    FOOT_POUND = 'foot_pound'

    def __str__(self) -> str:
        return str(self.value)



from typing import Any, Dict, Optional, Union, cast

import httpx

from ...client import Client
from ...models.mesh import Mesh
from ...models.error import Error
from ...models.image_type import ImageType
from ...models.file_export_format import FileExportFormat
from ...types import Response

def _get_kwargs(
	input_format: ImageType,
	output_format: FileExportFormat,
	body: bytes,
	*,
	client: Client,
) -> Dict[str, Any]:
	url = "{}/ai/image-to-3d/{input_format}/{output_format}".format(client.base_url, input_format=input_format, output_format=output_format)

	headers: Dict[str, Any] = client.get_headers()
	cookies: Dict[str, Any] = client.get_cookies()

	return {
		"url": url,
		"headers": headers,
		"cookies": cookies,
		"timeout": client.get_timeout(),
		"content": body,
	}


def _parse_response(*, response: httpx.Response) -> Optional[Union[Any, Mesh, Error]]:
	if response.status_code == 200:
		response_200 = Mesh.from_dict(response.json())
		return response_200
	if response.status_code == 400:
		response_4XX = Error.from_dict(response.json())
		return response_4XX
	if response.status_code == 500:
		response_5XX = Error.from_dict(response.json())
		return response_5XX
	return None


def _build_response(*, response: httpx.Response) -> Response[Union[Any, Mesh, Error]]:
	return Response(
		status_code=response.status_code,
		content=response.content,
		headers=response.headers,
		parsed=_parse_response(response=response),
	)


def sync_detailed(
	input_format: ImageType,
	output_format: FileExportFormat,
	body: bytes,
	*,
	client: Client,
) -> Response[Union[Any, Mesh, Error]]:
	kwargs = _get_kwargs(
		input_format=input_format,
		output_format=output_format,
		body=body,
		client=client,
	)

	response = httpx.post(
		verify=client.verify_ssl,
		**kwargs,
	)

	return _build_response(response=response)


def sync(
	input_format: ImageType,
	output_format: FileExportFormat,
	body: bytes,
	*,
	client: Client,
) -> Optional[Union[Any, Mesh, Error]]:
	""" This is an alpha endpoint. It will change in the future. The current output is honestly pretty bad. So if you find this endpoint, you get what you pay for, which currently is nothing. But in the future will be made a lot better. """

	return sync_detailed(
		input_format=input_format,
		output_format=output_format,
		body=body,
		client=client,
	).parsed


async def asyncio_detailed(
	input_format: ImageType,
	output_format: FileExportFormat,
	body: bytes,
	*,
	client: Client,
) -> Response[Union[Any, Mesh, Error]]:
	kwargs = _get_kwargs(
		input_format=input_format,
		output_format=output_format,
		body=body,
		client=client,
	)

	async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
		response = await _client.post(**kwargs)

	return _build_response(response=response)


async def asyncio(
	input_format: ImageType,
	output_format: FileExportFormat,
	body: bytes,
	*,
	client: Client,
) -> Optional[Union[Any, Mesh, Error]]:
	""" This is an alpha endpoint. It will change in the future. The current output is honestly pretty bad. So if you find this endpoint, you get what you pay for, which currently is nothing. But in the future will be made a lot better. """

	return (
		await asyncio_detailed(
		input_format=input_format,
		output_format=output_format,
		body=body,
			client=client,
		)
	).parsed



from enum import Enum


class AsyncApiCallType(str, Enum):
    FILE_CONVERSION = 'FileConversion'
    FILE2_D_VECTOR_CONVERSION = 'File2DVectorConversion'
    FILE_VOLUME = 'FileVolume'
    FILE_CENTER_OF_MASS = 'FileCenterOfMass'
    FILE_MASS = 'FileMass'
    FILE_DENSITY = 'FileDensity'
    FILE_SURFACE_AREA = 'FileSurfaceArea'

    def __str__(self) -> str:
        return str(self.value)



from typing import Any, Dict, List, Type, TypeVar, Union, cast

import attr

from ..models.ai_plugin_api import AiPluginApi
from ..models.ai_plugin_auth import AiPluginAuth
from ..types import UNSET, Unset

T = TypeVar("T", bound="AiPluginManifest")


@attr.s(auto_attribs=True)
class AiPluginManifest:
    """ """
    api: Union[Unset, AiPluginApi] = UNSET
    auth: Union[Unset, AiPluginAuth] = UNSET
    contact_email: Union[Unset, str] = UNSET
    description_for_human: Union[Unset, str] = UNSET
    description_for_model: Union[Unset, str] = UNSET
    legal_info_url: Union[Unset, str] = UNSET
    logo_url: Union[Unset, str] = UNSET
    name_for_human: Union[Unset, str] = UNSET
    name_for_model: Union[Unset, str] = UNSET
    schema_version: Union[Unset, str] = UNSET

    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        api: Union[Unset, str] = UNSET
        if not isinstance(self.api, Unset):
            api = self.api.value
        auth: Union[Unset, str] = UNSET
        if not isinstance(self.auth, Unset):
            auth = self.auth.value
        contact_email = self.contact_email
        description_for_human = self.description_for_human
        description_for_model = self.description_for_model
        legal_info_url = self.legal_info_url
        logo_url = self.logo_url
        name_for_human = self.name_for_human
        name_for_model = self.name_for_model
        schema_version = self.schema_version

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if api is not UNSET:
            field_dict['api'] = api
        if auth is not UNSET:
            field_dict['auth'] = auth
        if contact_email is not UNSET:
            field_dict['contact_email'] = contact_email
        if description_for_human is not UNSET:
            field_dict['description_for_human'] = description_for_human
        if description_for_model is not UNSET:
            field_dict['description_for_model'] = description_for_model
        if legal_info_url is not UNSET:
            field_dict['legal_info_url'] = legal_info_url
        if logo_url is not UNSET:
            field_dict['logo_url'] = logo_url
        if name_for_human is not UNSET:
            field_dict['name_for_human'] = name_for_human
        if name_for_model is not UNSET:
            field_dict['name_for_model'] = name_for_model
        if schema_version is not UNSET:
            field_dict['schema_version'] = schema_version

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        _api = d.pop("api", UNSET)
        api: Union[Unset, AiPluginApi]
        if isinstance(_api, Unset):
            api = UNSET
        else:
            api = AiPluginApi(_api)

        _auth = d.pop("auth", UNSET)
        auth: Union[Unset, AiPluginAuth]
        if isinstance(_auth, Unset):
            auth = UNSET
        else:
            auth = AiPluginAuth(_auth)

        contact_email = d.pop("contact_email", UNSET)

        description_for_human = d.pop("description_for_human", UNSET)

        description_for_model = d.pop("description_for_model", UNSET)

        legal_info_url = d.pop("legal_info_url", UNSET)

        logo_url = d.pop("logo_url", UNSET)

        name_for_human = d.pop("name_for_human", UNSET)

        name_for_model = d.pop("name_for_model", UNSET)

        schema_version = d.pop("schema_version", UNSET)

        ai_plugin_manifest = cls(
            api=api,
            auth=auth,
            contact_email=contact_email,
            description_for_human=description_for_human,
            description_for_model=description_for_model,
            legal_info_url=legal_info_url,
            logo_url=logo_url,
            name_for_human=name_for_human,
            name_for_model=name_for_model,
            schema_version=schema_version,
        )

        ai_plugin_manifest.additional_properties = d
        return ai_plugin_manifest

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class UnitDensityFormat(str, Enum):
    KILOGRAMS_PER_CUBIC_METER = 'kilograms_per_cubic_meter'
    GRAMS_PER_MILLILITER = 'grams_per_milliliter'
    KILOGRAMS_PER_LITER = 'kilograms_per_liter'
    OUNCES_PER_CUBIC_FOOT = 'ounces_per_cubic_foot'
    OUNCES_PER_CUBIC_INCH = 'ounces_per_cubic_inch'
    OUNCES_PER_GALLON = 'ounces_per_gallon'
    POUNDS_PER_CUBIC_FOOT = 'pounds_per_cubic_foot'
    POUNDS_PER_CUBIC_INCH = 'pounds_per_cubic_inch'
    POUNDS_PER_GALLON = 'pounds_per_gallon'
    SLUGS_PER_CUBIC_FOOT = 'slugs_per_cubic_foot'

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class FileImportFormat(str, Enum):
    DAE = 'dae'
    DXF = 'dxf'
    FBX = 'fbx'
    OBJ_ZIP = 'obj_zip'
    OBJ = 'obj'
    PLY = 'ply'
    STEP = 'step'
    STL = 'stl'
    SVG = 'svg'

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class PhysicsConstantName(str, Enum):
    PI = 'pi'
    C = 'c'
    SPEED_OF_LIGHT = 'speed_of_light'
    G = 'G'
    NEWTONIAN_GRAVITATION = 'newtonian_gravitation'
    H = 'h'
    PLANCK_CONST = 'planck_const'
    MU_0 = 'mu_0'
    VACUUM_PERMEABILITY = 'vacuum_permeability'
    E_0 = 'E_0'
    VACUUM_PERMITIVITY = 'vacuum_permitivity'
    Z_0 = 'Z_0'
    VACUUM_IMPEDANCE = 'vacuum_impedance'
    K_E = 'k_e'
    COULOMB_CONST = 'coulomb_const'
    E = 'e'
    ELEMENTARY_CHARGE = 'elementary_charge'
    M_E = 'm_e'
    ELECTRON_MASS = 'electron_mass'
    M_P = 'm_p'
    PROTON_MASS = 'proton_mass'
    MU_B = 'mu_B'
    BOHR_MAGNETON = 'bohr_magneton'
    NA = 'NA'
    AVOGADRO_NUM = 'avogadro_num'
    R = 'R'
    MOLAR_GAS_CONST = 'molar_gas_const'
    K_B = 'K_B'
    BOLTZMANN_CONST = 'boltzmann_const'
    F = 'F'
    FARADAY_CONST = 'faraday_const'
    SIGMA = 'sigma'
    STEFAN_BOLTZMANN_CONST = 'stefan_boltzmann_const'

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class UnitAccelerationFormat(str, Enum):
    METERS_PER_SECOND_SQUARED = 'meters_per_second_squared'
    FEET_PER_SECOND_SQUARED = 'feet_per_second_squared'
    STANDARD_GRAVITY = 'standard_gravity'

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class AiPluginAuthType(str, Enum):
    NONE = 'none'
    USER_HTTP = 'user_http'
    SERVICE_HTTP = 'service_http'
    OAUTH = 'oauth'

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class UnitTemperatureFormat(str, Enum):
    KELVIN = 'kelvin'
    CELSIUS = 'celsius'
    FAHRENHEIT = 'fahrenheit'
    REAUMUR = 'reaumur'
    RANKINE = 'rankine'

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class UnitAreaFormat(str, Enum):
    SQUARE_METER = 'square_meter'
    SQUARE_FOOT = 'square_foot'
    SQUARE_INCH = 'square_inch'
    SQUARE_MILE = 'square_mile'
    SQUARE_KILOMETER = 'square_kilometer'
    HECTARE = 'hectare'
    ACRE = 'acre'

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class UnitAngularVelocityFormat(str, Enum):
    RADIANS_PER_SECOND = 'radians_per_second'
    DEGREES_PER_SECOND = 'degrees_per_second'
    REVOLUTIONS_PER_MINUTE = 'revolutions_per_minute'
    MILLIARCSECONDS_PER_YEAR = 'milliarcseconds_per_year'

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class UnitAngleFormat(str, Enum):
    RADIAN = 'radian'
    DEGREE = 'degree'
    ARCMINUTE = 'arcminute'
    ARCSECOND = 'arcsecond'
    MILLIARCSECOND = 'milliarcsecond'
    TURN = 'turn'
    GRADIAN = 'gradian'

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class UnitTimeFormat(str, Enum):
    SECOND = 'second'
    MINUTE = 'minute'
    HOUR = 'hour'
    DAY = 'day'
    WEEK = 'week'
    YEAR = 'year'
    JULIAN_YEAR = 'julian_year'
    GREGORIAN_YEAR = 'gregorian_year'

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class UnitVelocityFormat(str, Enum):
    METERS_PER_SECOND = 'meters_per_second'
    FEET_PER_SECOND = 'feet_per_second'
    MILES_PER_HOUR = 'miles_per_hour'
    KILOMETERS_PER_HOUR = 'kilometers_per_hour'
    KNOT = 'knot'

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class UnitDataTransferRateFormat(str, Enum):
    BYTES_PER_SECOND = 'bytes_per_second'
    EXABYTES_PER_SECOND = 'exabytes_per_second'
    BITS_PER_SECOND = 'bits_per_second'
    EXABITS_PER_SECOND = 'exabits_per_second'

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class UnitForceFormat(str, Enum):
    NEWTON = 'newton'
    POUND = 'pound'
    DYNE = 'dyne'
    KILOPOND = 'kilopond'
    POUNDAL = 'poundal'

    def __str__(self) -> str:
        return str(self.value)
